==> libmp4v2-4.1.4-1-arm.pkg.tar.xz: usr/include/mp4v2/project.h <==
#ifndef MP4V2_PROJECT_H
#define MP4V2_PROJECT_H

/*****************************************************************************/

#define MP4V2_PROJECT_name            "MP4v2"
#define MP4V2_PROJECT_name_lower      "mp4v2"
#define MP4V2_PROJECT_name_upper      "MP4V2"
#define MP4V2_PROJECT_name_formal     "MP4v2 2.0.0"
#define MP4V2_PROJECT_url_website     "http://code.google.com/p/mp4v2"
#define MP4V2_PROJECT_url_downloads   "http://code.google.com/p/mp4v2/downloads/list"
#define MP4V2_PROJECT_url_discussion  "http://groups.google.com/group/mp4v2"
#define MP4V2_PROJECT_irc             "irc://irc.freenode.net/handbrake"
#define MP4V2_PROJECT_bugreport       "<kidjan@gmail.com>"
#define MP4V2_PROJECT_version         "2.0.0"
#define MP4V2_PROJECT_version_hex     0x00020000
#define MP4V2_PROJECT_version_major   2
#define MP4V2_PROJECT_version_minor   0
#define MP4V2_PROJECT_version_point   0
#define MP4V2_PROJECT_repo_url        "https://mp4v2.googlecode.com/svn/releases/2.0.0"
#define MP4V2_PROJECT_repo_branch     "2.0.0"
#define MP4V2_PROJECT_repo_root       "https://mp4v2.googlecode.com/svn"
#define MP4V2_PROJECT_repo_uuid       "6e6572fa-98a6-11dd-ad9f-f77439c74b79"
#define MP4V2_PROJECT_repo_rev        493
#define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
#define MP4V2_PROJECT_repo_type       "stable"
#define MP4V2_PROJECT_build           "Mon Mar 22 13:34:19 UTC 2021"

/*****************************************************************************/

#endif /* MP4V2_PROJECT_H */

==> libmp4v2-4.1.6-1-arm.pkg.tar.xz: usr/include/mp4v2/project.h <==
#ifndef MP4V2_PROJECT_H
#define MP4V2_PROJECT_H

/*****************************************************************************/

#define MP4V2_PROJECT_name            "MP4v2"
#define MP4V2_PROJECT_name_lower      "mp4v2"
#define MP4V2_PROJECT_name_upper      "MP4V2"
#define MP4V2_PROJECT_name_formal     "MP4v2 2.0.0"
#define MP4V2_PROJECT_url_website     "http://code.google.com/p/mp4v2"
#define MP4V2_PROJECT_url_downloads   "http://code.google.com/p/mp4v2/downloads/list"
#define MP4V2_PROJECT_url_discussion  "http://groups.google.com/group/mp4v2"
#define MP4V2_PROJECT_irc             "irc://irc.freenode.net/handbrake"
#define MP4V2_PROJECT_bugreport       "<kidjan@gmail.com>"
#define MP4V2_PROJECT_version         "2.0.0"
#define MP4V2_PROJECT_version_hex     0x00020000
#define MP4V2_PROJECT_version_major   2
#define MP4V2_PROJECT_version_minor   0
#define MP4V2_PROJECT_version_point   0
#define MP4V2_PROJECT_repo_url        "https://mp4v2.googlecode.com/svn/releases/2.0.0"
#define MP4V2_PROJECT_repo_branch     "2.0.0"
#define MP4V2_PROJECT_repo_root       "https://mp4v2.googlecode.com/svn"
#define MP4V2_PROJECT_repo_uuid       "6e6572fa-98a6-11dd-ad9f-f77439c74b79"
#define MP4V2_PROJECT_repo_rev        493
#define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
#define MP4V2_PROJECT_repo_type       "stable"
#define MP4V2_PROJECT_build           "Sun May  2 18:55:45 UTC 2021"

/*****************************************************************************/

#endif /* MP4V2_PROJECT_H */
